TopLevelExampleBuilder

Struct TopLevelExampleBuilder 

pub struct TopLevelExampleBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> TopLevelExampleBuilder<S>

pub fn build(self) -> TopLevelExample
where S: IsComplete,

Finish building and return the requested object

pub fn shown(self, value: i32) -> TopLevelExampleBuilder<SetShown<S>>
where S::Shown: IsUnset,

Optional (Some / Option setters). Default: 42.

Doesn’t match the on(u32, ...) type pattern, and thus shows the default in the docs. If you want to select all members, then use the pattern _.

pub fn maybe_shown( self, value: Option<i32>, ) -> TopLevelExampleBuilder<SetShown<S>>
where S::Shown: IsUnset,

Optional (Some / Option setters). Default: 42.

Doesn’t match the on(u32, ...) type pattern, and thus shows the default in the docs. If you want to select all members, then use the pattern _.

pub fn hidden(self, value: u32) -> TopLevelExampleBuilder<SetHidden<S>>
where S::Hidden: IsUnset,

Optional (Some / Option setters). Matches the on(u32, ...) type pattern, and thus skips the default in the docs.

pub fn maybe_hidden( self, value: Option<u32>, ) -> TopLevelExampleBuilder<SetHidden<S>>
where S::Hidden: IsUnset,

Optional (Some / Option setters). Matches the on(u32, ...) type pattern, and thus skips the default in the docs.