GreeterBuilderCustom

Struct GreeterBuilderCustom 

pub struct GreeterBuilderCustom<'f1, S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with call().

Implementations

Source

impl<'f1, S: State> GreeterBuilderCustom<'f1, S>

pub fn call(self) -> String
where S: IsComplete,

Finishes building and performs the requested action.

pub fn name(self, value: &'f1 str) -> GreeterBuilderCustom<'f1, SetName<S>>
where S::Name: IsUnset,

Required.

Name of the person to greet.

Example:

bon_sandbox::functions::greet().name("John");
pub fn age(self, value: u32) -> GreeterBuilderCustom<'f1, SetAge<S>>
where S::Age: IsUnset,

Required.

Age expressed in full years passed since the birth date.