pub struct GreeterBuilderCustom<'f1, S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with call().
Implementations
Sourceimpl<'f1, S: State> GreeterBuilderCustom<'f1, S>
impl<'f1, S: State> GreeterBuilderCustom<'f1, S>
Sourcepub fn call(self) -> Stringwhere
S: IsComplete,
pub fn call(self) -> Stringwhere
S: IsComplete,
Finishes building and performs the requested action.
Sourcepub fn name(self, value: &'f1 str) -> GreeterBuilderCustom<'f1, SetName<S>>where
S::Name: IsUnset,
pub fn name(self, value: &'f1 str) -> GreeterBuilderCustom<'f1, SetName<S>>where
S::Name: IsUnset,
Required.
Name of the person to greet.
Example:
bon_sandbox::functions::greet().name("John");Sourcepub fn age(self, value: u32) -> GreeterBuilderCustom<'f1, SetAge<S>>where
S::Age: IsUnset,
pub fn age(self, value: u32) -> GreeterBuilderCustom<'f1, SetAge<S>>where
S::Age: IsUnset,
Required.
Age expressed in full years passed since the birth date.